"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.hasAdminPrivileges = void 0;
const __1 = require("..");
/**
 * Test if the current user token has admin privileges.
 *
 * If this function return false, it means that operations that
 * requires admin rights cannot be done, even if the account is
 * configured with admin right. Functions that require admin right
 * would return the error 5 (admin right required).
 *
 * Example: `netapi.NetUserAdd` function can be called only
 * if the user token has admin privilege.
 *
 * @export
 * @returns {boolean}
 */
function hasAdminPrivileges() {
    const sid = __1.sspi.AllocateAndInitializeSid();
    const result = __1.sspi.CheckTokenMembership(sid);
    __1.sspi.FreeSid(sid);
    return result;
}
exports.hasAdminPrivileges = hasAdminPrivileges;
//# sourceMappingURL=uac.js.map